@@ -38,6 +38,8 @@ import time
 import unittest
 import uuid
 
+from urlparse import urlparse, parse_qsl
+
 from twisted.application import internet, service
 from twisted.internet import defer
 from twisted.internet.defer import Deferred, inlineCallbacks
@@ -48,10 +50,12 @@ from ubuntuone.storageprotocol import protocol_pb2, sharersp, delta, request
 from ubuntuone.storageprotocol.client import (
     StorageClient, CreateUDF, ListVolumes, DeleteVolume, GetDelta, Unlink,
     Authenticate, MakeFile, MakeDir, PutContent, Move, BytesMessageProducer,
-    oauth, TwistedTimestampChecker, tx_timestamp_checker,
+    TwistedTimestampChecker, tx_timestamp_checker,
 )
+
 from ubuntuone.storageprotocol import volumes
 from tests import test_delta_info
+from oauthlib.oauth1 import Client
 
 # let's not get picky about aatributes outside __init__ in tests
 # pylint: disable=W0201
@@ -296,7 +300,7 @@ class ClientTestCase(unittest.TestCase):
                           'hello')
         #create a response and message
         share_resp = sharersp.NotifyShareHolder.from_params(
-           uuid.uuid4(), uuid.uuid4(), 'sname', 'byu', 'tou', 'View')
+            uuid.uuid4(), uuid.uuid4(), 'sname', 'byu', 'tou', 'View')
         proto_msg = protocol_pb2.Message()
         proto_msg.type = protocol_pb2.Message.NOTIFY_SHARE
         share_resp.dump_to_msg(proto_msg.notify_share)
@@ -795,31 +799,43 @@ class TestAuth(RequestTestCase):
 
     def test_oauth_authenticate_uses_server_timestamp(self):
         """The oauth authentication uses the server timestamp."""
-        fromcandt_call = []
+        timestamps = []
 
-        fake_token = oauth.OAuthToken('token', 'token_secret')
-        fake_consumer = oauth.OAuthConsumer('consumer_key', 'consumer_secret')
+        original_sign = Client.sign
 
-        fake_timestamp = object()
+        def fake_sign(self, *args, **kwargs):
+            """A fake Client.sign()."""
+            url, headers, body = original_sign(self, *args, **kwargs)
+            timestamps.extend(
+                value for name, value in parse_qsl(urlparse(url).query)
+                if name == 'oauth_timestamp')
+            return url, headers, body
+
+        fake_timestamp = '801'
         timestamp_d = Deferred()
         self.patch(tx_timestamp_checker, "get_faithful_time",
                    lambda: timestamp_d)
-        original_fromcandt = oauth.OAuthRequest.from_consumer_and_token
 
-        @staticmethod
-        def fake_from_consumer_and_token(**kwargs):
-            """A fake from_consumer_and_token."""
-            fromcandt_call.append(kwargs)
-            return original_fromcandt(**kwargs)
-
-        self.patch(oauth.OAuthRequest, "from_consumer_and_token",
-                   fake_from_consumer_and_token)
+        self.patch(Client, 'sign', fake_sign)
         protocol = FakedProtocol()
-        protocol.oauth_authenticate(fake_consumer, fake_token)
-        self.assertEqual(len(fromcandt_call), 0)
+        # For backward compatibility of the API, oauth_authenticate() takes a
+        # consumer object and a token object.  Both of those must have .key
+        # and .secret attributes.  In modern OAuth1 (i.e. RFC 5849)
+        # terminology, the consumer is really the OAuth client, and the token
+        # is really the OAuth resource owner.
+
+        class OAuthClient:
+            key = 'consumer_key'
+            secret = 'consumer_secret'
+
+        class OAuthResourceOwner:
+            key = 'token'
+            secret = 'token_secret'
+        protocol.oauth_authenticate(OAuthResourceOwner, OAuthClient)
+        self.assertEqual(len(timestamps), 0)
         timestamp_d.callback(fake_timestamp)
-        parameters = fromcandt_call[0]["parameters"]
-        self.assertEqual(parameters["oauth_timestamp"], fake_timestamp)
+        self.assertEqual(len(timestamps), 1)
+        self.assertEqual(timestamps[0], fake_timestamp)
 
 
 class RootResource(resource.Resource):
