@@ -162,7 +162,7 @@ class StorageClient(request.RequestHandler):
                         signature_method=SIGNATURE_PLAINTEXT,
                         signature_type=SIGNATURE_TYPE_QUERY,
                         timestamp=timestamp)
-        url, headers, body = client.sign('storage://server')
+        url, headers, body = client.sign('http://server')
         # Parse out the authentication parameters from the query string.
         auth_parameters = dict(
             (name, value) for name, value in
